@@ -30,6 +30,7 @@
 #include <dbus/dbus-glib-lowlevel.h>
 #include <dbus/dbus-glib-bindings.h>
 #include <libedataserver/e-data-server-module.h>
+#include <libedataserver/e-data-server-util.h>
 #include <libedataserver/e-log.h>
 #include "e-book-backend-factory.h"
 #include "e-data-book-factory.h"
@@ -384,46 +385,6 @@ backup_start (DBusGProxy *proxy, EDataBookFactory *factory)
   g_mutex_unlock (factory->priv->books_lock);
 }
 
-/* delete_directory() copied from telepathy-haze (file src/main.c)
- * and relicensed from GPL to LGPL by the author.
- *
- * Copyright (C) 2007 Will Thompson
- */
-static gboolean
-delete_directory (const char *path)
-{
-  const gchar *child_path;
-  GDir *dir;
-  gboolean ret = TRUE;
-
-  dir = g_dir_open (path, 0, NULL);
-  if (!dir)
-    return FALSE;
-
-  while (ret && (child_path = g_dir_read_name (dir))) {
-    gchar *child_full_path;
-
-    child_full_path = g_build_filename (path, child_path, NULL);
-
-    if (g_file_test (child_full_path, G_FILE_TEST_IS_DIR)) {
-      if (!delete_directory (child_full_path))
-        ret = FALSE;
-    } else {
-      if (g_unlink (child_full_path) != 0)
-        ret = FALSE;
-    }
-
-    g_free (child_full_path);
-  }
-
-  g_dir_close (dir);
-
-  if (ret)
-    ret = !g_rmdir (path);
-
-  return ret;
-}
-
 #define E_DATA_BOOK_FACTORY_SERVICE_NAME "org.gnome.evolution.dataserver.AddressBook"
 
 int
@@ -495,7 +456,7 @@ main (int argc, char **argv)
 
   if (g_file_test (restore_dir, G_FILE_TEST_IS_DIR)) {
     /* Delete the temporary directory just in case it exists */
-    delete_directory (tmp_dir);
+    e_util_recursive_rmdir (tmp_dir);
 
     /* Rename the .osso-abook directory (if it exists) to a temporary
      * location as a backup in case the restore procedure fails */
@@ -506,7 +467,7 @@ main (int argc, char **argv)
       /* Now actually restore the backup */
       if (g_rename (restore_dir, data_dir) == 0) {
         /* Done, cleanup the temporary stuff */
-        delete_directory (tmp_dir);
+        e_util_recursive_rmdir (tmp_dir);
       } else {
         g_critical ("Failed to restore the backup, using the old data");
         /* Failed to restore the backup, let's try at least not to lose
